/*
The software and accompanying written material (including instructions for use) are provided "as is" without warranty of any kind. 
Further, Yaqingda does not warrant, guarantee or make any representations regarding the use or the results of use, 
of the Software or written materials in terms of correctness, reliability, 
accuracy or fitness for purpose. The entire risk as to the results and performance of the software is assumed by you. 
Should the software be defective, you and not Yaqingda. or its dealers, agents,
distributors or employees, assume the entire cost of all necessary repair, servicing and correction.

The above is the only warranty of any kind, either express or implied,
including but not limited to the warranties of merchantability and fitness for purpose, 
that Yaqingda makes regarding this product. No oral or written information or advise given by Yaqingda. 
or its dealers, agents, distributors or employees shall create a warranty or in any way increase the scope of this warranty.

Neither Yaqingda nor anyone else who has been involved in the creation, 
production or delivery of this product shall be liable for any direct, 
indirect, consequential or incidental damages ( including damages for loss of
business profits, business interruption, loss of business information, and the like.) 
arising out of the use or inability to use this product even if Yaqingda has been advised of the possibility of such damages.

#Copyright Notice
Yaqingda copyrights this specification. No part of this specification may be reproduced in any form or means, without the prior written consent of Yaqingda.

#Disclaimer
This specification is preliminary and is subject to change at any time without notice. Yaqingda assumes no responsibility for any errors contained herein.

©2019 Guangzhou Yaqingda Intelligent Systems Co.Ltd. All rights reserved.
*/

/**
 * 单、双屏专用版本
 * 
 * 
 */

const xapi = require('xapi');

/**
 * //检查连接的屏幕数量同步函数
 * @param {*} resolve 
 * @param {*} reject 
 */
function Yaqingda_checkConnectionCount_P (resolve, reject) {

  xapi.status.get('Video Output Connector').then((result) => {

    var count = 0;
    for (var i = 0; i < result.length; i++) {
      var temp = result[i]
      if (temp.Connected == 'True') {
        count++
      }
    }
    console.log('当前有' + count + '设备连接');
    resolve(count);
  });
}

/**
 * 设置MonitorRole为Auto
 * @param {*} id 
 */
function Yaqingda_setMonitorRoleToAuto (id) {

  xapi.config.set('Video Output Connector ' + id + ' MonitorRole', 'Auto').
    catch((error) => {
      console.error(error);
    });
}


/**
 * 设置所有MonitorRole为Auto
 */
function Yaqingda_setAllMonitorRoleToAuto () {
  var p1 = new Promise(Yaqingda_checkConnectionCount_P);
  var p2 = p1.then(function (result) {
    if (result > 0) {
      for (var i = 1; i <= result; i++) {
        Yaqingda_setMonitorRoleToAuto(i)

      }
      console.log('设置成功');
    } else {
      console.log('设置错误');
    }
  });
  var p3 = p2.
    catch(function (reason) {
      console.log('失败：' + reason);
    });
}


/**
 * 重置视频矩阵
 */
function Yaqingda_resetMatrixReset () {

  xapi.command('Video Matrix Reset');
}


/**
 * 设置显示屏模式为Auto
 */
function Yaqingda_setVideoMonitorsToAuto () {
  xapi.config.set('Video Monitors', "Auto").
    catch((error) => {
      console.error(error);
    });
}

/**
 * 设置本地视频
 */
function Yaqingda_MiniSelfView (mode, fullscreenMode, monitorRole) {

  if (monitorRole) {
    xapi.command('Video Selfview Set', {
      Mode: mode,
      FullscreenMode: fullscreenMode,
      OnMonitorRole: monitorRole
    });
  } else {
    xapi.command('Video Selfview Set', {
      Mode: mode,
      FullscreenMode: fullscreenMode

    });
  }
}

/**
 * 重置状态
 */
function Yaqingda_reset () {

  Yaqingda_MiniSelfView("on", "Off", null);
  Yaqingda_setVideoMonitorsToAuto();
  Yaqingda_setAllMonitorRoleToAuto();
  Yaqingda_resetMatrixReset();
  // Yaqingda_checkConnectionCount()
}

function Yaqingda_clearPromptMsg () {
  xapi.command('UserInterface Message Prompt Clear');
}


/**
 * 比较版本大小，aVersion > aVersion 返回true ，以外返回false
 * @param {*} aVersion 
 * @param {*} bVersion 
 */
function compareVersion (aVersion, bVersion) {
  var a = (aVersion != null ? aVersion : "");
  var b = (bVersion != null ? bVersion : "");
  var aStringArray = a.split(".");
  var bStringArray = b.split(".");
  var loopCount = Math.min(aStringArray.length, bStringArray.length);
  for (var i = 0; i < loopCount; i++) {
    if (parseInt(aStringArray[i]) > parseInt(bStringArray[i])) {
      return true;
    }
    else if (parseInt(aStringArray[i]) < parseInt(bStringArray[i])) {
      return false;
    }
  }
  return aStringArray.length > bStringArray.length;
}

//***初始化
xapi.config.set('HttpClient Mode:', 'On').catch((error) => {
  console.error(error);
});

xapi.config.set('Macros AutoStart:', 'On').catch((error) => {
  console.error(error);
});

xapi.command('Macros Macro Activate', {
  Name: 'active'
});


/**
 * 加入会议时重新加载参会人
 */
xapi.event.on('CallSuccessful', (event) => {
  setTimeout(function () {

    //初始化屏幕默认layout
    var p1 = new Promise(Yaqingda_checkConnectionCount_P);
    p1.then(function (result) {
      if (result == 2) {
        Yaqingda_reset();

      } 
    }).catch(function (reason) {
      console.log('失败：' + reason);
    });

  }, 1000);
})

/
xapi.event.on('CallDisconnect', (event) => {

  //初始化屏幕默认layout
  var p1 = new Promise(Yaqingda_checkConnectionCount_P);
  p1.then(function (result) {
    if (result >= 2) {
      Yaqingda_reset();

    }
  }).catch(function (reason) {
    console.log('失败：' + reason);
  });
})

var msg = {
  Yaqingda_showPromptMsg: function (text) {
    xapi.command('UserInterface Message Prompt Display', {
      Title: '提示',
      Text: text,
      Duration: 5
    });
  },

  Yaqingda_showPromptResponseMsg: function (text, feedbackId, option) {
    xapi.command('UserInterface Message Prompt Display', {
      Title: '提示',
      Text: text,
      FeedbackId: feedbackId,
      'Option.1': option
    });
  },
  Yaqingda_showalert: function (text, duration = 5) {

    xapi.command('UserInterface Message Alert Display', {
      Title: '提示',
      Text: text,
      Duration: duration,
    });
  },
  showPromptTwoOptions: function (text, feedbackId, option1, option2) {
    xapi.command('UserInterface Message Prompt Display', {
      Title: '提示',
      Text: text,
      FeedbackId: feedbackId,
      'Option.1': option1,
      'Option.2': option2
    });
  },
  Yaqingda_showPromptMsgWithoutDuration: function (text) {
    xapi.command('UserInterface Message Prompt Display', {
      Title: '提示',
      Text: text
    });
  }
}

function handleError (error) {
  console.log('Error', error);
  msg.Yaqingda_showPromptMsg('系统异常:' + error.message);
}

//如果系统版本低于 9.8，不能使用http get，提示“请先升级终端系统软件”
var p1 = new Promise((resolve, reject) => {
  xapi.status.get('Provisioning Software Current VersionId').then((versionId) => {
    versionId = versionId.split(' ')[0]
    resolve(versionId);
  }).catch(handleError);
});
var p2 = p1.then(function (result) {
  if (compareVersion('9.8.0', result.replace('ce', '').replace('tc', ''))) {
    msg.Yaqingda_showalert('请先升级终端系统软件！', 0);
    return;
  } else {
    setTimeout(function () {
      Yaqingda_clearPromptMsg();
    }, 3000);
  }
})

