export { read}
const xapi = require('xapi');

const PREFIX = 'const json = ';
const DATABASE_NAME = 'DB'; // name of the macro with db contents
const SERVER_HOST = 'https://www.1table.cn'
const version = '1.0.0' 

// Read database contents
async function read() {
   // Load contents
   let contents;
   try {
      let macro = await xapi.command('Macros Macro Get', { Name: DATABASE_NAME, Content: true })
      contents = macro.Macro[0].Content.substring(PREFIX.length);
   }
   catch(err) {
      console.error(`cannot load contents from macro: ${DATABASE_NAME}`);
      throw new Error("DB_ACCESS_ERROR");
   }
   
   // Parse contents
   try {
      console.debug(`DB contains: ${contents}`);
      let data = JSON.parse(contents);
      console.debug('DB successfully parsed');
      return data;
   }
   catch (err) {
      console.error('DB is corrupted, cannot JSON parse the DB');
      throw new Error('DB_PARSE_ERROR');
   }
}

// Write database contents
async function write(data) {
   // Serialize data as JSON and append prefix
   let contents;
   try {
      contents = PREFIX + JSON.stringify(data);
   }
   catch (err) {
      console.debug('Contents cannot be serialized to JSON');
      throw new Error('DB_SERIALIZE_ERROR');
   }
   
   // Write
   try {
      let res = await xapi.command('Macros Macro Save', { Name: DATABASE_NAME, OverWrite: true, body: contents });
      return (res.status == 'OK');
   }
   catch (err) {
      console.error(`cannot write contents to macro: ${DATABASE_NAME}`);
      throw new Error('DB_ACCESS_ERROR');
   }
}

xapi.on('ready', async () => {
  xapi.status.get('Network 1 Ethernet MacAddress').then((mac_address)=>{
    console.log(mac_address)
     var payload = JSON.stringify({
      'mac_address': mac_address
    });
     console.log(payload);
     xapi.command(
      'HttpClient Post',
      {
        Header: ["Content-Type: application/json"],
        Url: SERVER_HOST+"/api/v1/getsn",
        ResultBody: "PlainText"
      },payload)
      .then(async(response) => {
         console.log(`received response with status code: ${response.StatusCode}`);

         if (response.StatusCode == 200) {
           console.log(`response body: ${response.Body}`)
            let result = JSON.parse(response.Body);
            if(result.errno == 0){
              await write({ sn :  result.data ,version:version});
              let data = await read();
              console.log(`sn is: ${data.sn}`)
            }
          
            return;
         }
      })
      .catch((err) => {
         console.log(`failed with err message: ${err}`);
      })
  })
});

   

