/*
The software and accompanying written material (including instructions for use) are provided "as is" without warranty of any kind. 
Further, Yaqingda does not warrant, guarantee or make any representations regarding the use or the results of use, 
of the Software or written materials in terms of correctness, reliability, 
accuracy or fitness for purpose. The entire risk as to the results and performance of the software is assumed by you. 
Should the software be defective, you and not Yaqingda. or its dealers, agents,
distributors or employees, assume the entire cost of all necessary repair, servicing and correction.

The above is the only warranty of any kind, either express or implied,
including but not limited to the warranties of merchantability and fitness for purpose, 
that Yaqingda makes regarding this product. No oral or written information or advise given by Yaqingda. 
or its dealers, agents, distributors or employees shall create a warranty or in any way increase the scope of this warranty.

Neither Yaqingda nor anyone else who has been involved in the creation, 
production or delivery of this product shall be liable for any direct, 
indirect, consequential or incidental damages ( including damages for loss of
business profits, business interruption, loss of business information, and the like.) 
arising out of the use or inability to use this product even if Yaqingda has been advised of the possibility of such damages.

#Copyright Notice
Yaqingda copyrights this specification. No part of this specification may be reproduced in any form or means, without the prior written consent of Yaqingda.

#Disclaimer
This specification is preliminary and is subject to change at any time without notice. Yaqingda assumes no responsibility for any errors contained herein.

©2019 Guangzhou Yaqingda Intelligent Systems Co.Ltd. All rights reserved.
*/

/**
 * 单、双屏专用版本
 * 
 */
const xapi = require('xapi');
const serverUrl = 'https://touch10.1table.cn:8188'
const verNum = 'V1.0.0' //客户端版本号
const appType = '单、双屏版本Touch10';
const domain = '@1table.cn'

function Yaqingda_showalert (text, duration = 5) {

  xapi.command('UserInterface Message Alert Display', {
    Title: '提示',
    Text: text,
    Duration: duration,
  });
}

/**
 * 重置状态
 */
function Yaqingda_reset () {

  Yaqingda_MiniSelfView("on", "Off", null);
  Yaqingda_setVideoMonitors("Auto");
  Yaqingda_setAllMonitorRole('Auto');
  Yaqingda_resetMatrixReset();
  setSelfview();
}

function setSelfview () {
  xapi.config.get('Provisioning LoginName').then((defaultVolume) => {

    var temp = '666' + defaultVolume + domain
    console.log('本端账号:' + temp)

    xapi.status.get('Call').then((volume) => {
      // console.log(volume[0].RemoteNumber)
      console.log(volume[0].id)
      // var bcontrol = false;
      if (volume[0].RemoteNumber === temp) {
        if (compareVersion('2.7', cmsVersion)) {
          return;
        }
        var mode = 'skip'

        xapi.config.get('Provisioning LoginName').then((user_name) => {
          xapi.command('HttpClient Get', {
            Header: ["Content-Type: application/json"],
            Url: serverUrl + "/panePlacementSelfPaneMode?user_name=" + user_name + domain + '&mode=' + mode
          }).then((result) => {
            console.log(`panePlacementSelfPaneMode status:${result.Body}`)

          }).catch((err) => {
            console.log("failed: " + err.message)
          });
        })
      }

    })
  });
}

/**
 * 比较版本大小，aVersion > aVersion 返回true ，以外返回false
 * @param {*} aVersion 
 * @param {*} bVersion 
 */
function compareVersion (aVersion, bVersion) {
  var a = (aVersion != null ? aVersion : "");
  var b = (bVersion != null ? bVersion : "");
  var aStringArray = a.split(".");
  var bStringArray = b.split(".");
  var loopCount = Math.min(aStringArray.length, bStringArray.length);
  for (var i = 0; i < loopCount; i++) {
    if (parseInt(aStringArray[i]) > parseInt(bStringArray[i])) {
      return true;
    }
    else if (parseInt(aStringArray[i]) < parseInt(bStringArray[i])) {
      return false;
    }
  }
  return aStringArray.length > bStringArray.length;
}

function Yaqingda_getCmsVersion () {

  xapi.command('HttpClient Get', {
    Header: ["Content-Type: application/json"],
    Url: serverUrl + "/getCmsVersion"
  }).then((result) => {
    console.log(`cms version:${result.Body}`)
    var body = JSON.parse(result.Body)
    cmsVersion = body.version
  }).catch((err) => {
    console.log("failed: " + err.message)
  });

}


/**
 * 设置本地视频
 */
function Yaqingda_MiniSelfView (mode, fullscreenMode, monitorRole) {

  if (monitorRole) {
    xapi.command('Video Selfview Set', {
      Mode: mode,
      FullscreenMode: fullscreenMode,
      OnMonitorRole: monitorRole
    });
  } else {
    xapi.command('Video Selfview Set', {
      Mode: mode,
      FullscreenMode: fullscreenMode

    });
  }

}


/**
 * 设置显示屏模式
 */
function Yaqingda_setVideoMonitors (monitors) {
  xapi.config.set('Video Monitors', monitors).
    catch((error) => {
      console.error(error);
    });
}

/**
 * 设置所有MonitorRole
 */
function Yaqingda_setAllMonitorRole (monitorRole) {
  var p1 = new Promise(Yaqingda_checkConnectionCount_P);
  var p2 = p1.then(function (result) {
    if (result > 0) {

      for (let i = 1; i <= result; i++) {
        setTimeout(() => {
          Yaqingda_setMonitorRole(i, monitorRole)
        }, 100);

      }

    } else {
      console.log('设置错误');
    }
  });
  var p3 = p2.
    catch(function (reason) {
      console.log('失败：' + reason);
    });
}


/**
 * 重置视频矩阵
 */
function Yaqingda_resetMatrixReset () {
  xapi.command('Video Matrix Reset');
}

/**
 * 设置MonitorRole
 * @param {*} id 
 * @param {*} monitorRole 
 */
function Yaqingda_setMonitorRole (id, monitorRole) {

  xapi.config.set('Video Output Connector ' + id + ' MonitorRole', monitorRole).
    catch((error) => {
      console.error(error);
    });

}

/**
 * 设置所有屏幕显示本地视频
 */
function Yaqingda_setAllScreenToSelfView () {
  Yaqingda_setVideoMonitors("Single");
  Yaqingda_setAllMonitorRole('Auto');
  Yaqingda_MiniSelfView("on", "On", null);

}


function Yaqingda_addListenerToScreen () {
  /**
   * panel事件
   */
  xapi.event.on('UserInterface Extensions Panel Clicked', (event) => {
    console.log('panel控制');

   if (event.PanelId === 'panel_active') {
      xapi.command('UserInterface Extensions Widget SetValue ',
        { WidgetId: 'widget_appversion', value: (appType + verNum) }).catch(handleError);
    }

  })

  xapi.event.on('UserInterface Extensions Widget Action', (event) => {

    if (event.Type !== 'clicked') {
      return
    }
    //屏幕控制（默认）
    if (event.WidgetId === 'case1_button' && event.Type === 'clicked') {
      var p1 = new Promise(Yaqingda_checkConnectionCount_P);
      p1.then(function (result) {
        if (result == 2) {

          Yaqingda_reset();
        }
        else {
          Yaqingda_showalert('您当前状态为非双屏状态，无法使用该功能')
          Yaqingda_reset();
        }
      }).catch(function (reason) {
        console.log('失败：' + reason);
      });

    }
    //屏幕控制（双屏切换）
    else if (event.WidgetId === 'case2_button' && event.Type === 'clicked') {

      var p1 = new Promise(Yaqingda_checkConnectionCount_P);
      p1.then(function (result) {
        if (result == 2) {
          xapi.command('Video Matrix Swap', {
            OutputA: '1',
            OutputB: '2'
          });
        }
        else {
          Yaqingda_showalert('您当前状态为非双屏状态，无法使用该功能')
          Yaqingda_reset();
        }
      }).catch(function (reason) {
        console.log('失败：' + reason);
      });
    }
    //屏幕控制（双屏PPT）
    else if (event.WidgetId === 'case3_button' && event.Type === 'clicked') {

      var p1 = new Promise(Yaqingda_checkConnectionCount_P);
      p1.then(function (result) {
        if (result == 2) {
          xapi.status.get('Call').then((volume) => {
            if (volume) {
              Yaqingda_reset();
              Yaqingda_setAllMonitorRole('PresentationOnly');
            }
          })
        }
        else {
          Yaqingda_showalert('您当前状态为非双屏状态，无法使用该功能')
          Yaqingda_reset();
        }
      }).catch(function (reason) {
        console.log('失败：' + reason);
      });

    }
    //屏幕控制（双屏本地视频）
    else if (event.WidgetId === 'case4_button' && event.Type === 'clicked') {
      var p1 = new Promise(Yaqingda_checkConnectionCount_P);
      p1.then(function (result) {
        if (result == 2) {
          xapi.status.get('Call').then((volume) => {
            if (volume) {
              Yaqingda_reset();
              Yaqingda_setAllScreenToSelfView();
            }
          })
        }
        else {
          Yaqingda_showalert('您当前状态为非双屏状态，无法使用该功能')
          Yaqingda_reset();
        }
      }).catch(function (reason) {
        console.log('失败：' + reason);
      });

    }
    //屏幕控制（双视频）
    else if (event.WidgetId === 'case6_button' && event.Type === 'clicked') {
      var p1 = new Promise(Yaqingda_checkConnectionCount_P);
      p1.then(function (result) {
        if (result == 2) {

          Yaqingda_reset();
          Yaqingda_MiniSelfView("on", "on", "Second");
          // Yaqingda_setSelfViewMonitorRole("Second");
        }
        else {
          Yaqingda_showalert('您当前状态为非双屏状态，无法使用该功能')
          Yaqingda_reset();
        }
      }).catch(function (reason) {
        console.log('失败：' + reason);
      });

    }

  })

}


/**
 * 检查连接的屏幕数量同步函数
 * @param {*} resolve 
 * @param {*} reject 
 */
function Yaqingda_checkConnectionCount_P (resolve, reject) {

  xapi.status.get('Video Output Connector').then((result) => {

    var count = 0;
    for (var i = 0; i < result.length; i++) {
      var temp = result[i];
      if (temp.Connected == 'True') {
        count++;
      }
    }
    console.log('当前有' + count + '块屏幕连接');
    resolve(count);
  });


}

function handleError (error) {
  console.log('Error', error);
  Yaqingda_showalert('系统异常:' + error.message);
}

let cmsVersion = ''


//初始化屏幕控制面板
// xapi.event.on('CallSuccessful', (event) => {
xapi.status.get('SystemUnit ProductPlatform').then((platform) => {
  // console.log(`终端型号为：${platform}`);
  //DX80、DX70、SX10不支持
  if (platform == "DX80" || platform == "DX70" || platform == "SX10") {

    xapi.command('UserInterface Extensions Panel Remove', { PanelId: 'panel_screencontrol' })
      .catch(function (reason) {
        console.log('删除panel失败：' + reason);
      });
  }

  xapi.command('UserInterface Extensions Panel Remove', { PanelId: 'panel_instruction' })
      .catch(function (reason) {
        console.log('删除panel失败：' + reason);
      });
      
  Yaqingda_addListenerToScreen();

}).catch(handleError);

Yaqingda_getCmsVersion();
